@@ -1,7 +1,7 @@
 package Getopt::Long::EvenLess;
 
-our $DATE = '2016-12-03'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $DATE = '2017-01-11'; # DATE
+our $VERSION = '0.08'; # VERSION
 
 # let's be minimalistic
 #use strict 'subs', 'vars';
@@ -10,6 +10,31 @@ our $VERSION = '0.07'; # VERSION
 our @EXPORT   = qw(GetOptions);
 our @EXPORT_OK = qw(GetOptionsFromArray);
 
+my $config = {
+    pass_through => 0,
+};
+
+sub Configure {
+    my $old_config = { %$config };
+
+    if (ref($_[0]) eq 'HASH') {
+        for (keys %{$_[0]}) {
+            $config->{$_} = $_[0]{$_};
+        }
+    } else {
+        for (@_) {
+            if ($_ eq 'pass_through') {
+                $config->{pass_through} = 1;
+            } elsif ($_ eq 'no_pass_through') {
+                $config->{pass_through} = 0;
+            } else {
+                die "Unknown configuration '$_'";
+            }
+        }
+    }
+    $old_config;
+}
+
 sub import {
     my $pkg = shift;
     my $caller = caller;
@@ -57,13 +82,17 @@ sub GetOptionsFromArray {
             }
         }
         if (!@candidates) {
-            warn "Unknown option: $wanted\n";
-            $success = 0;
+            unless ($config->{pass_through}) {
+                warn "Unknown option: $wanted\n";
+                $success = 0;
+            }
             return undef; # means unknown
         } elsif (@candidates > 1) {
-            warn "Option $wanted is ambiguous (" .
-                join(", ", @candidates) . ")\n";
-            $success = 0;
+            unless ($config->{pass_through}) {
+                warn "Option $wanted is ambiguous (" .
+                    join(", ", @candidates) . ")\n";
+                $success = 0;
+            }
             return ''; # means ambiguous
         }
         return $candidates[0];
@@ -92,6 +121,7 @@ sub GetOptionsFromArray {
             my ($used_name, $val_in_opt) = ($1, $2);
             my $opt = $code_find_opt->($used_name);
             if (!defined($opt)) {
+                # unknown option
                 push @remaining, $argv->[$i];
                 next ELEM;
             } elsif (!length($opt)) {
@@ -182,12 +212,10 @@ Getopt::Long::EvenLess - Like Getopt::Long::Less, but with even less features
 
 =head1 VERSION
 
-This document describes version 0.07 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2016-12-03.
+This document describes version 0.08 of Getopt::Long::EvenLess (from Perl distribution Getopt-Long-EvenLess), released on 2017-01-11.
 
 =head1 DESCRIPTION
 
-B<EXPERIMENTAL WORK>.
-
 This module (GLEL for short) is a reimplementation of L<Getopt::Long> (GL for
 short), but with much less features. It's an even more stripped down version of
 L<Getopt::Long::Less> (GLL for short) and is perhaps less convenient to use for
@@ -201,10 +229,16 @@ Compared to GL and GLL, it:
 
 =over
 
-=item * does not have Configure()
+=item * minimum Configure() support
 
-Nothing to configure, no different modes of operation. GLEL is equivalent to GL
-in this mode: bundling, no_ignore_case, no_getopt_compat, gnu_compat, permute.
+Only these configurations are known: pass_through, no_pass_through (default).
+
+GLEL is equivalent to GL in this mode: bundling, no_ignore_case,
+no_getopt_compat, gnu_compat, permute.
+
+No support for configuring via import options e.g.:
+
+ use Getopt::Long qw(:config pass_through);
 
 =item * does not support increment (C<foo+>)
 
@@ -227,7 +261,7 @@ object as its first argument.
 
 The result?
 
-B<Amount of code>. GLEL is about 175 lines of code, while GL is about 1500.
+B<Amount of code>. GLEL 0.07 is about 175 lines of code, while GL is about 1500.
 Sure, if you I<really> want to be minimalistic, you can use this single line of
 code to get options:
 
@@ -240,25 +274,57 @@ handler, etc.
 
 B<Startup overhead>. Here's a sample startup overhead benchmark:
 
-                            Rate      run_gl     load_gl   run_gl_less  load_gl_less run_gl_evenless load_gl_evenless   perl
- run_gl            76.33+-0.31/s          --       -1.2%        -67.0%        -67.6%          -80.7%           -80.9% -87.5%
- load_gl           77.29+-0.31/s 1.26+-0.58%          --        -66.6%        -67.2%          -80.5%           -80.6% -87.4%
- run_gl_less      231.56+-0.31/s 203.4+-1.3% 199.6+-1.3%            --         -1.8%          -41.4%           -42.0% -62.1%
- load_gl_less     235.76+-0.29/s 208.9+-1.3%   205+-1.3%   1.81+-0.19%            --          -40.4%           -41.0% -61.4%
- run_gl_evenless    395.4+-2.2/s   418+-3.5% 411.5+-3.5%  70.74+-0.96%   67.7+-0.94%              --            -1.0% -35.3%
- load_gl_evenless   399.4+-1.1/s 423.2+-2.6% 416.7+-2.5%  72.48+-0.53%  69.41+-0.51%     1.02+-0.62%               -- -34.7%
- perl               611.2+-1.1/s 700.7+-3.6% 690.8+-3.5% 163.95+-0.61% 159.25+-0.58%     54.59+-0.9%     53.03+-0.51%     --
+                           Rate      run_gl     load_gl run_gl_less load_gl_less load_gl_evenless run_gl_evenless   perl
+ run_gl            66.4+-0.64/s          --       -5.9%      -71.3%       -71.5%           -80.9%          -81.3% -89.6%
+ load_gl          70.59+-0.16/s     6.3+-1%          --      -69.4%       -69.7%           -79.7%          -80.1% -89.0%
+ run_gl_less         231+-1.1/s 247.9+-3.7% 227.3+-1.7%          --        -0.8%           -33.4%          -34.8% -64.0%
+ load_gl_less      232.8+-1.9/s 250.6+-4.4% 229.8+-2.7% 0.78+-0.94%           --           -32.9%          -34.3% -63.7%
+ load_gl_evenless    347+-9.7/s    423+-15%    392+-14%  50.2+-4.3%   49.1+-4.3%               --           -2.1% -45.9%
+ run_gl_evenless     354.5+-4/s 433.9+-7.9% 402.2+-5.7%  53.4+-1.9%   52.3+-2.1%        2.2+-3.1%              -- -44.7%
+ perl                641+-3.7/s    865+-11% 808.1+-5.6% 177.5+-2.1%  175.3+-2.7%       84.7+-5.3%      80.8+-2.3%     --
  
  Average times:
-   perl            :     1.6361ms
-   load_gl_evenless:     2.5038ms
-   run_gl_evenless :     2.5291ms
-   load_gl_less    :     4.2416ms
-   run_gl_less     :     4.3185ms
-   load_gl         :    12.9383ms
-   run_gl          :    13.1010ms
+   perl            :     1.5601ms
+   run_gl_evenless :     2.8209ms
+   load_gl_evenless:     2.8818ms
+   load_gl_less    :     4.2955ms
+   run_gl_less     :     4.3290ms
+   load_gl         :    14.1663ms
+   run_gl          :    15.0602ms
 
-=for Pod::Coverage .+
+=head1 FUNCTIONS
+
+=head2 Configure(@configs | \%config) => hash
+
+Set configuration. Known configurations:
+
+=over
+
+=item * pass_through
+
+Ignore errors (unknown/ambiguous option) and still make GetOptions return true.
+
+=item * no_pass_through (default)
+
+=back
+
+Return old configuration data. To restore old configuration data you can pass it
+back to C<Configure()>, e.g.:
+
+ my $orig_conf = Getopt::Long::EvenLess::Configure("pass_through");
+ # ...
+ Getopt::Long::EvenLess::Configure($orig_conf);
+
+=head2 GetOptions(%spec) => bool
+
+Shortcut for:
+
+ GetOptionsFromArray(\@ARGV, %spec)
+
+=head2 GetOptionsFromArray(\@ary, %spec) => bool
+
+Get (and strip) options from C<@ary>. Return true on success or false on failure
+(unknown option, etc).
 
 =head1 HOMEPAGE
 
@@ -290,7 +356,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2016 by perlancar@cpan.org.
+This software is copyright (c) 2017 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
